@@ -9,7 +9,7 @@ use crate::{
         Painter,
         components::{
             data_table::{DrawInfo, SelectionState},
-            time_graph::{GraphData, variants::percent::PercentTimeGraph},
+            time_graph::{GraphData, PercentTimeGraph},
         },
         drawing_utils::should_hide_x_label,
     },
@@ -132,10 +132,8 @@ impl Painter {
                 .iter()
                 .enumerate()
                 .map(|(itx, values)| {
-                    let style = if show_avg_cpu && itx == AVG_POSITION {
+                    let style = if show_avg_cpu && itx == 0 {
                         self.styles.avg_cpu_colour
-                    } else if itx == ALL_POSITION {
-                        self.styles.all_cpu_colour
                     } else {
                         self.styles.cpu_colour_styles
                             [(itx - show_avg_offset) % self.styles.cpu_colour_styles.len()]
@@ -143,9 +141,11 @@ impl Painter {
 
                     GraphData::default().style(style).time(time).values(values)
                 })
+                .rev()
                 .collect()
         } else if let Some(CpuData { .. }) = cpu_entries.get(current_scroll_position - 1) {
             // We generally subtract one from current scroll position because of the all entry.
+            // TODO: Do this a bit better (e.g. we can just do if let Some(_) = cpu_points.get())
 
             let style = if show_avg_cpu && current_scroll_position == AVG_POSITION {
                 self.styles.avg_cpu_colour
@@ -188,7 +188,7 @@ impl Painter {
 
             // TODO: Maybe hide load avg if too long? Or maybe the CPU part.
             let title = {
-                #[cfg(target_family = "unix")]
+                #[cfg(unix)]
                 {
                     let load_avg = &data.load_avg_harvest;
                     let load_avg_str = format!(
